@@ -16,8 +16,6 @@ class AppSetup(Controller):
     container_registry = 'localhost:5001'
     backend_path = ''
     frontend_path = ''
-    backend_image_tag = ''
-    frontend_image_tag = ''
     class Meta:
         label = 'items'
         stacked_type = 'embedded'
@@ -76,14 +74,14 @@ class AppSetup(Controller):
                 print('Unable to find frontend dir. Are you running kluff from inside your plugin dir?')
                 sys.exit()
 
-            self.backend_image_tag = f'{plugin_name}:backend'
-            self.frontend_image_tag = f'{plugin_name}:frontend'
+            backend_image_tag = f'{plugin_name}:backend'
+            frontend_image_tag = f'{plugin_name}:frontend'
 
-            os.system(f'cd {self.backend_path} && docker build -t {self.backend_image_tag} .')
-            os.system(f'docker run -it -p 5000:5000 -d {self.backend_image_tag}')
+            os.system(f'cd {self.backend_path} && docker build -t {backend_image_tag} .')
+            os.system(f'docker run -it -p 5000:5000 -d {backend_image_tag}')
 
-            os.system(f'cd {self.frontend_path} && docker build -t {self.frontend_image_tag} .')
-            os.system(f'docker run -it -p 3000:3000 -d {self.frontend_image_tag}')
+            os.system(f'cd {self.frontend_path} && docker build -t {frontend_image_tag} .')
+            os.system(f'docker run -it -p 3000:3000 -d {frontend_image_tag}')
 
         except OSError as e:
             raise CommandError(e)
@@ -94,9 +92,11 @@ class AppSetup(Controller):
     def deploy(self):
         self.app.log.info(f'deploying plugin')
         try:
+            plugin_name = os.path.dirname(self.backend_path)
+            backend_image_tag = f'{plugin_name}-backend:latest'
             os.system(f'cd {self.backend_path}')
-            os.system(f'docker build -t {self.backend_image_tag} .')
-            os.system(f'docker tag {self.backend_image_tag} {self.container_registry}/{self.backend_image_tag}')
-            os.system(f'docker push {self.container_registry}/{self.backend_image_tag}')
+            os.system(f'docker build -t {backend_image_tag} .')
+            os.system(f'docker tag {backend_image_tag} {self.container_registry}/{backend_image_tag}')
+            os.system(f'docker push {self.container_registry}/{backend_image_tag}')
         except OSError as e:
             raise CommandError(e)
